***********************************************************
`cfr`: a Python package for Climate Field Reconstruction
***********************************************************

`cfr` aims to provide a universal framework for climate field reconstruction (CFR).
It provides a toolkit for

+ the analysis/visualization of the proxy records,
+ the processing of the climate model simulations and instrumental observations,
+ the calibration and running of the proxy system models (PSMs, `Evans et al., 2013 <https://doi.org/10.1016/j.quascirev.2013.05.024>`_),
+ the preparation and running of the multiple reconstruction frameworks/algorithms, such as LMR (`Hakim et al., 2016 <https://doi.org/10.1002/2016JD024751>`_; `Tardif et al., 2019 <https://doi.org/https://doi.org/10.5194/cp-15-1251-2019>`_) and GraphEM (`Guillot et al., 2015 <https://doi.org/10.1214/14-AOAS794>`_), and
+ the validation of the reconstructions, etc.

For more details, please refer to the documentation linked below.

Documentation
=============

+ Homepage: https://fzhu2e.github.io/cfr
+ Installation: https://fzhu2e.github.io/cfr/ug-installation.html